@@ -495,7 +495,7 @@ def MarginalResults(DirName, CaseName, OptModel, mTEPES):
     AppendData = pd.concat(AppendData)
     AppendData.to_frame(name='LSRMC').reset_index().pivot_table(index=['level_0','level_1','level_2'], columns='level_3', values='LSRMC').rename_axis(['Scenario','Period','LoadLevel'], axis=0).rename_axis([None], axis=1).to_csv(_path+'/oT_Result_LSRMC_'+CaseName+'.csv', sep=',')
 
-    LSRMC = OutputToFile.loc[:,:]
+    LSRMC = AppendData.loc[:,:,:,:]
 
     for sc,p in mTEPES.sc*mTEPES.p:
         chart = LinePlots(sc, p, LSRMC, 'Node', 'LoadLevel', 'EUR/MWh', 'average')
@@ -922,7 +922,7 @@ def NetworkMapResults(DirName, CaseName, OptModel, mTEPES):
     fig = go.Figure()
 
     # Add nodes
-    fig.add_trace(go.Scattermapbox(lat=loc_df['Lat'], lon=loc_df['Lon'], mode='markers', marker=go.scattermapbox.Marker(size=loc_df['Size']*10, sizeref=1.1, sizemode='area', color='LightSkyBlue',), hoverinfo='text', text='<br>Zone: '+loc_df['index']+'<br>[Lon, Lat]: '+'('+loc_df['Lon'].astype(str)+', '+loc_df['Lat'].astype(str)+')'+'<br>Zone: '+loc_df['Zone']+'<br>Demand: '+loc_df['Demand'].astype(str)+' MW',))
+    fig.add_trace(go.Scattermapbox(lat=loc_df['Lat'], lon=loc_df['Lon'], mode='markers', marker=go.scattermapbox.Marker(size=loc_df['Size']*10, sizeref=1.1, sizemode="area", color='LightSkyBlue',), hoverinfo='text', text='<br>Node: ' + loc_df['index'] + '<br>[Lon, Lat]: ' + '(' + loc_df['Lon'].astype(str) + ', ' + loc_df['Lat'].astype(str) + ')' + '<br>Zone: ' + loc_df['Zone'] + '<br>Demand: ' + loc_df['Demand'].astype(str) + ' MW',))
 
     # Add edges
     for ni, nf, cc in mTEPES.la:
