@@ -1,5 +1,5 @@
 """
-Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - December 08, 2021
+Open Generation and Transmission Operation and Expansion Planning Model with RES and ESS (openTEPES) - January 22, 2021
 """
 
 import time
@@ -8,7 +8,7 @@ import psutil
 from   pyomo.opt     import SolverFactory
 from   pyomo.environ import Suffix, Set
 
-def ProblemSolving(DirName, CaseName, SolverName, OptModel, mTEPES):
+def ProblemSolving(DirName, CaseName, SolverName, OptModel, mTEPES, pIndLogConsole):
     print('Problem solving                        ****')
     _path = os.path.join(DirName, CaseName)
     StartTime = time.time()
@@ -37,15 +37,18 @@ def ProblemSolving(DirName, CaseName, SolverName, OptModel, mTEPES):
         # Solver.options['BarQCPConvTol' ] = 0.025
         Solver.options['MIPGap'        ] = 0.01
         Solver.options['Threads'       ] = int((psutil.cpu_count(logical=True) + psutil.cpu_count(logical=False))/2)
-        Solver.options['TimeLimit'     ] =    7200
-        Solver.options['IterationLimit'] = 7200000
-    if mTEPES.pIndBinGenInvest()*len(mTEPES.gc) + mTEPES.pIndBinNetInvest()*len(mTEPES.lc) + mTEPES.pIndBinGenOperat()*len(mTEPES.nr) + mTEPES.pIndBinLineCommit()*len(mTEPES.la) + len(mTEPES.g2g) == 0:
+        Solver.options['TimeLimit'     ] =    9600
+        Solver.options['IterationLimit'] = 9600000
+    if mTEPES.pIndBinGenInvest()*len(mTEPES.gc) + mTEPES.pIndBinGenRetire()*len(mTEPES.gd) + mTEPES.pIndBinNetInvest()*len(mTEPES.lc) + mTEPES.pIndBinGenOperat()*len(mTEPES.nr) + mTEPES.pIndBinLineCommit()*len(mTEPES.la) + len(mTEPES.g2g) == 0:
         if SolverName == 'gurobi' or SolverName == 'mosek':
             Solver.options['relax_integrality'] =  1  # introduced to show results of the dual variables
             Solver.options['Crossover'        ] = -1
         OptModel.dual = Suffix(direction=Suffix.IMPORT)
         OptModel.rc   = Suffix(direction=Suffix.IMPORT)
-    SolverResults = Solver.solve(OptModel, tee=True, report_timing=True)               # tee=True displays the log of the solver
+    if pIndLogConsole == 1:
+        SolverResults = Solver.solve(OptModel, tee=True , report_timing=True )               # tee=True displays the log of the solver
+    else:
+        SolverResults = Solver.solve(OptModel, tee=False, report_timing=False)
     assert str(SolverResults.solver.termination_condition) == 'optimal'
     SolverResults.write()                                                              # summary of the solver results
 
@@ -92,7 +95,10 @@ def ProblemSolving(DirName, CaseName, SolverName, OptModel, mTEPES):
             Solver.options['Crossover'        ] = -1
         OptModel.dual = Suffix(direction=Suffix.IMPORT)
         OptModel.rc   = Suffix(direction=Suffix.IMPORT)
-        SolverResults = Solver.solve(OptModel, tee=True, report_timing=True, warmstart=True)   # tee=True displays the log of the solver
+        if pIndLogConsole == 1:
+            SolverResults = Solver.solve(OptModel, tee=True , report_timing=True , warmstart=True)   # tee=True displays the log of the solver
+        else:
+            SolverResults = Solver.solve(OptModel, tee=False, report_timing=False, warmstart=True)
         SolverResults.write()                                                                  # summary of the solver results
 
     SolvingTime = time.time() - StartTime
